@@ -10,7 +10,7 @@ class education_credit_phase_out(Variable):
     definition_period = YEAR
 
     def formula(tax_unit, period, parameters):
-        education = parameters(period).irs.credits.education
+        education = parameters(period).gov.irs.credits.education
         agi = tax_unit("adjusted_gross_income", period)
         is_joint = tax_unit("tax_unit_is_joint", period)
         phase_out_start = where(
